@@ -24,4 +24,6 @@
 #
 ###############################################################################
 
-__version__ = u'19.6.1'
+__version__ = '22.1.1'
+
+__build__ = u'00000000-0000000'
